@@ -8,8 +8,6 @@ OC.L10N.register(
     "Cheers!" : "Geluk!",
     "Calendar" : "Kalender",
     "Confirm" : "Bevestig",
-    "Anniversary" : "Herdenking",
-    "Personal" : "Persoonlik",
     "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
     "Today" : "Vandag",
     "Day" : "Dag",
@@ -59,27 +57,25 @@ OC.L10N.register(
     "Unknown" : "Onbekend",
     "Accept" : "Aanvaar",
     "Tentative" : "Tentatief",
+    "Attendees" : "Bywoners",
     "All day" : "Heeldag",
     "Repeat" : "Herhaal",
     "never" : "nooit",
     "after" : "na",
     "available" : "beskikbaar",
-    "More" : "Nog",
     "Global" : "Globaal",
     "Subscribe" : "Teken in",
+    "Personal" : "Persoonlik",
     "Details" : "Details",
-    "Attendees" : "Bywoners",
     "Resources" : "Hulpbronne",
     "Close" : "Sluit",
+    "Anniversary" : "Herdenking",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Daily" : "Daagliks",
     "Weekly" : "Weekliks",
     "Other" : "Ander",
     "Status" : "Status",
     "Confirmed" : "Bevestig",
-    "Categories" : "Kategorieë",
-    "Commuting" : "In die verkeer",
-    "Mail" : "Pos",
-    "Birthday" : "Verjaardag"
+    "Categories" : "Kategorieë"
 },
 "nplurals=2; plural=(n != 1);");
