@@ -66,11 +66,12 @@ OC.L10N.register(
     "Delete file" : "Borrar archivo",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Available" : "Disponible",
+    "Done" : "Terminado",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
+    "Attendees" : "Asistentes",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
@@ -78,12 +79,10 @@ OC.L10N.register(
     "first" : "primero",
     "last" : "último",
     "available" : "disponible",
-    "More" : "Más",
     "Global" : "Global",
     "Subscribe" : "Suscribirse",
     "Personal" : "Personal",
     "Details" : "Detalles",
-    "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
@@ -96,10 +95,6 @@ OC.L10N.register(
     "When shared hide this event" : "Al compartir, ocultar este evento ",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
-    "Categories" : "Categoría",
-    "Talk" : "Hablar",
-    "Movie" : "Película",
-    "Mail" : "Correo Electrónico",
-    "Birthday" : "Fecha de nacimiento"
+    "Categories" : "Categoría"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
