@@ -6,36 +6,48 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
     "Open »%s«" : "Ava »%s«",
     "Cheers!" : "Tervist!",
+    "Upcoming events" : "Tulekul sündmused",
+    "More events" : "Rohkem sündmuseid",
+    "No more events today" : "Täna rohkem sündmuseid pole",
+    "No upcoming events" : "Tulekul sündmuseid pole",
     "Calendar" : "Kalender",
     "Confirm" : "Kinnita",
+    "Date:" : "Kuupäev:",
     "Where:" : "Kus:",
-    "Anniversary" : "Aastapäev",
-    "Appointment" : "Kohtumine",
-    "Personal" : "Isiklik",
-    "Vacation" : "Puhkus",
+    "Comment:" : "Kommentaar:",
     "Previous day" : "Eelmine päev",
     "Previous week" : "Eelmine nädal",
+    "Previous year" : "Eelmine aasta",
     "Previous month" : "Eelmine kuu",
     "Next day" : "Järgmine päev",
     "Next week" : "Järgmine nädal",
+    "Next year" : "Järgmine aasta",
     "Next month" : "Järgmine kuu",
+    "Event" : "Sündmus",
+    "Create new event" : "Lisa uus sündmus",
     "Today" : "Täna",
     "Day" : "Päev",
     "Week" : "Nädal",
     "Month" : "Kuu",
+    "Year" : "Aasta",
+    "List" : "Nimekiri",
     "Preview" : "Eelvaade",
     "Copy link" : "Kopeeri link",
     "Edit" : "Redigeeri",
     "Delete" : "Kustuta",
+    "Add new" : "Lisa uus",
     "Untitled calendar" : "Nimetu kalender",
+    "Edit calendar" : "Muuda kalendrit",
     "New calendar" : "Uus kalender",
     "Export" : "Ekspordi",
+    "Trash bin" : "Prügikast",
     "Name" : "Nimi",
     "Deleted" : "Kustutatud",
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
     "Empty trash bin" : "Tühjenda prügikast",
     "Internal link" : "Sisemine link",
+    "Copy internal link" : "Kopeeri sisemine link",
     "Share link" : "Jaga link",
     "Copy public link" : "Kopeeri avalik link",
     "Delete share link" : "Kustuta jagamise link",
@@ -49,11 +61,29 @@ OC.L10N.register(
     "Cancel" : "Loobu",
     "Invalid location selected" : "Vigane asukoht valitud",
     "Automatic" : "Automaatne",
+    "Previous period" : "Eelmine periood",
+    "Next period" : "Järgmine periood",
+    "Views" : "Vaated",
+    "Day view" : "Päeva vaade",
+    "Week view" : "Nädala vaade",
+    "Month view" : "Kuu vaade",
+    "Year view" : "Aasta vaade",
     "List view" : "Nimekirjavaade",
     "Actions" : "Tegevused",
+    "Create event" : "Lisa sündmus",
     "Show week numbers" : "Näita nädalanumberid",
+    "Calendar settings" : "Kalendri seaded",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutit"],
+    "0 minutes" : "0 minutit",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} tund","{duration} tundi"],
+    "_{duration} day_::_{duration} days_" : ["{duration} päev","{duration} päeva"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} nädal","{duration} nädalat"],
+    "_{duration} month_::_{duration} months_" : ["{duration} kuu","{duration} kuud"],
+    "_{duration} year_::_{duration} years_" : ["{duration} aasta","{duration} aastat"],
     "Location" : "Asukoht",
     "Description" : "Kirjeldus",
+    "Visibility" : "Nähtavus",
+    "Duration" : "Kestus",
     "to" : "saaja",
     "Add" : "Lisa",
     "Monday" : "Esmaspäev",
@@ -66,28 +96,43 @@ OC.L10N.register(
     "Update" : "Uuenda",
     "Your email address" : "Sinu e-posti aadress",
     "Notification" : "Teavitus",
-    "Email" : "Epost",
+    "Email" : "E-post",
     "On date" : "Kuupäeval",
+    "_second_::_seconds_" : ["sekund","sekundit"],
+    "_minute_::_minutes_" : ["minut","minutit"],
+    "_hour_::_hours_" : ["tund","tundi"],
+    "_day_::_days_" : ["päev","päeva"],
+    "_week_::_weeks_" : ["nädal","nädalat"],
+    "No attachments" : "Manuseid pole",
+    "Add from Files" : "Lisa failidest",
+    "Upload from device" : "Laadi üles seadmest",
     "Delete file" : "Kustuta fail",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
+    "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
+    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
+    "Done" : "Valmis",
     "Unknown" : "Teadmata",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
     "Tentative" : "Esialgne",
-    "Send email" : "Saada kiri",
+    "Attendees" : "Osalejad",
+    "Remove group" : "Eemalda grupp",
     "All day" : "Kogu päev",
     "Repeat" : "Korda",
     "never" : "mitte kunagi",
     "after" : "pärast",
-    "More" : "Rohkem",
+    "_month_::_months_" : ["kuu","kuud"],
+    "Does not repeat" : "Ei kordu",
     "Global" : "Üldine",
     "Subscribe" : "Telli",
+    "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
-    "Attendees" : "Osalejad",
     "Resources" : "Ressursid",
     "Close" : "Sulge",
+    "Anniversary" : "Aastapäev",
+    "Appointment" : "Kohtumine",
+    "Vacation" : "Puhkus",
     "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
-    "Does not repeat" : "Ei kordu",
     "Daily" : "Iga päev",
     "Weekly" : "Iga nädal",
     "Monthly" : "Igakuine",
@@ -99,67 +144,6 @@ OC.L10N.register(
     "Status" : "Staatus",
     "Confirmed" : "Kinnitatud",
     "Categories" : "Kategooriad",
-    "Presentation" : "Esitlus",
-    "Talk" : "Talk",
-    "Camping" : "Telkimine",
-    "Camp" : "Laager",
-    "Movie" : "Film",
-    "Cinema" : "Kino",
-    "Graduation" : "Lõpetamine",
-    "Brainstorm" : "Ajutorm",
-    "Baseball" : "Pesapall",
-    "Office" : "Kontor",
-    "Mail" : "Kirjad",
-    "Soccer" : "Jalgpall",
-    "Football" : "Ameerika jalgpall",
-    "Drive" : "Sõit",
-    "Bicycle" : "Jalgratas",
-    "Biking" : "Jalgrattaga sõitmine",
-    "Basketball" : "Korvpall",
-    "Fishing" : "Kalapüük",
-    "Hiking" : "Matkaminee",
-    "Hike" : "Matk",
-    "Art" : "Kunst",
-    "Exhibition" : "Näitus",
-    "Museum" : "Muuseum",
-    "Pilates" : "Pilates",
-    "Park" : "Park",
-    "Studying" : "Õppimine",
-    "Doctor" : "Arst",
-    "Health" : "Tervis",
-    "Dentist" : "Hambaarst",
-    "Interview" : "Intervjuu",
-    "Training" : "Koolitus",
-    "Work out" : "Trenn",
-    "Working out" : "Treening",
-    "Barber" : "Habemeajaja",
-    "Haircut" : "Juukselõikus",
-    "Exam" : "Eksam",
-    "Fireworks" : "Ilutulestik",
-    "Running" : "Jooksmine",
-    "Go for a run" : "Mine jooksma",
-    "Marathon" : "Maraton",
-    "Call" : "Telefonikõne",
-    "Calling" : "Helistamine",
-    "Christmas" : "Jõulud",
-    "Conference" : "Konverents",
-    "Pizza" : "Pitsa",
-    "Travelling" : "Reisimine",
-    "Journey" : "Teekond",
-    "Collaborate" : "Koostöö",
-    "Pair" : "Paar",
-    "Lecture" : "Loeng",
-    "Seminar" : "Seminar",
-    "Photograph" : "Foto",
-    "Party" : "Pidu",
-    "Celebration" : "Tähistamine",
-    "Celebrate" : "Tähista",
-    "Birthday" : "Sünnipäev",
-    "Skate" : "Uisutamine",
-    "Skateboard" : "Rula",
-    "Wine tasting" : "Veini degusteerimine",
-    "Golf" : "Golf",
-    "Dinner" : "Õhtusöök",
     "User not found" : "Kasutajat ei leitud"
 },
 "nplurals=2; plural=(n != 1);");
