@@ -9,8 +9,6 @@ OC.L10N.register(
     "Calendar" : "კალენდარი",
     "Confirm" : "დადასტურება",
     "Where:" : "სად:",
-    "Anniversary" : "დაბადების დღე",
-    "Personal" : "პირადი",
     "Today" : "დღეს",
     "Day" : "დღე",
     "Week" : "კვირა",
@@ -54,23 +52,24 @@ OC.L10N.register(
     "Email" : "ელ-ფოსტა",
     "Delete file" : "გაუქმდეს ფაილი",
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
+    "Done" : "დასრულდა",
     "Unknown" : "ამოუცნობი",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
     "Tentative" : "საცდელი",
-    "Send email" : "ელ-წერილის გაგზავნა",
+    "Attendees" : "დამსწრეები",
     "All day" : "მთელი დღე",
     "Repeat" : "გამეორება",
     "never" : "არასდროს",
     "after" : "შემდეგ",
     "available" : "ხელმისაწვდომი",
-    "More" : "უფრო მეტი",
     "Global" : "გლობალური",
     "Subscribe" : "გამოწერა",
+    "Personal" : "პირადი",
     "Details" : "დეტლაები",
-    "Attendees" : "დამსწრეები",
     "Resources" : "რესურსები",
     "Close" : "დახურვა",
+    "Anniversary" : "დაბადების დღე",
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
     "Daily" : "ყოველდღიური",
     "Weekly" : "ყოველკვირეული",
@@ -80,9 +79,6 @@ OC.L10N.register(
     "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
     "Status" : "სტატუსი",
     "Confirmed" : "დადასტურებლია",
-    "Categories" : "კატეგორიები",
-    "Talk" : "საუბარი",
-    "Mail" : "ფოსტა",
-    "Birthday" : "დაბადების დრე"
+    "Categories" : "კატეგორიები"
 },
 "nplurals=2; plural=(n!=1);");
