@@ -10,15 +10,6 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Date:" : "Data :",
     "Where:" : "Ont :",
-    "Anniversary" : "Anniversari",
-    "Appointment" : "Rendetz-vos",
-    "Business" : "Afar",
-    "Education" : "Educacion",
-    "Holiday" : "Vacanças",
-    "Meeting" : "Reünion",
-    "Personal" : "Personal",
-    "Travel" : "Viatge",
-    "Vacation" : "Vacanças",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -111,7 +102,9 @@ OC.L10N.register(
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
-    "Send email" : "Enviar email",
+    "Attendees" : "Convidats",
+    "Remove group" : "Suprimir lo grop",
+    "Remove color" : "Suprimir la color",
     "Event title" : "Títol de l’eveniment",
     "All day" : "Tota la jornada",
     "Repeat" : "Repetir",
@@ -127,14 +120,12 @@ OC.L10N.register(
     "_year_::_years_" : ["annada","annadas"],
     "weekday" : "dimenjada",
     "weekend day" : "jorn de la setmana",
-    "No recurrence" : "Cap d’ocurréncia",
     "Suggestions" : "Suggestions",
     "Add resource" : "Apondre ressorsa",
     "available" : "disponible",
     "unavailable" : "indisponible",
     "Room type" : "Tipe de sala",
     "Any" : "Quina que siá",
-    "More" : "Mai",
     "Pick a time" : "Causir una ora",
     "Pick a date" : "Causir una data",
     "from {formattedDate}" : "a partir de {formattedDate}",
@@ -142,14 +133,23 @@ OC.L10N.register(
     "Type to search time zone" : "Picar per cercar un fus orari",
     "Global" : "Global",
     "Subscribe" : "S'abonar",
+    "Personal" : "Personal",
     "Create a new event" : "Crear un eveniment novèl",
     "[Today]" : "[Uèi]",
     "[Tomorrow]" : "[Deman]",
     "[Yesterday]" : "[Ièr]",
     "[Last] dddd" : "dddd [passat]",
     "Details" : "Detalhs",
-    "Attendees" : "Convidats",
     "Close" : "Tampar",
+    "Untitled event" : "Eveniment sens nom",
+    "Anniversary" : "Anniversari",
+    "Appointment" : "Rendetz-vos",
+    "Business" : "Afar",
+    "Education" : "Educacion",
+    "Holiday" : "Vacanças",
+    "Meeting" : "Reünion",
+    "Travel" : "Viatge",
+    "Vacation" : "Vacanças",
     "Daily" : "Cada jorn",
     "Weekly" : "Cada setmana",
     "Monthly" : "Cada mes",
@@ -159,7 +159,6 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
-    "Untitled event" : "Eveniment sens nom",
     "Untitled task" : "Prètzfach sens nom",
     "Other" : "Autre",
     "Add a location" : "Apondre un lòc",
@@ -170,54 +169,6 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
-    "Commuting" : "En comunicacion",
-    "Invoice" : "Factura",
-    "Finance" : "Finança",
-    "Bank" : "Banca",
-    "Money" : "Moneda",
-    "Wedding" : "Maridatge",
-    "Dog" : "Can",
-    "Concert" : "Concèrt",
-    "Festival" : "Festenal",
-    "Theater" : "Teatre",
-    "Theatre" : "Teatre",
-    "Presentation" : "Presentacion",
-    "Talk" : "Talk",
-    "Speech" : "Discutida",
-    "Election" : "Eleccion",
-    "Voting" : "Vòte",
-    "Vote" : "Vòte",
-    "Garden" : "Òrt",
-    "Farm" : "Bòria",
-    "Movie" : "Film",
-    "Cinema" : "Cinèma",
-    "Graduation" : "Remesa dels diplòmas",
-    "Brainstorm" : "Pluèja d’idèa",
-    "Audit" : "Audit",
-    "Inspection" : "Inspeccion",
-    "Mail" : "Mail",
-    "Gaming" : "Vidèo-jòc",
-    "Bicycle" : "Bicicleta",
-    "Bike" : "Bicicleta",
-    "Fishing" : "Pesca",
-    "Hiking" : "Escalada",
-    "Art" : "Arts",
-    "Museum" : "Musèu",
-    "Studying" : "Estudis",
-    "Doctor" : "Mètge",
-    "Health" : "Santat",
-    "Dentist" : "Dentista",
-    "Training" : "Entraïnament",
-    "Sports" : "Espòrt",
-    "Written test" : "Test escrich",
-    "Oral test" : "Test oral",
-    "Christmas" : "Nadal",
-    "Conference" : "Conferéncia",
-    "Pizza" : "Pizza",
-    "Travelling" : "Viatge",
-    "Party" : "Fèsta",
-    "Birthday" : "Data de naissença",
-    "Shopping" : "Crompas",
     "User not found" : "Utilizaire pas trobat"
 },
 "nplurals=2; plural=(n > 1);");
