@@ -9,8 +9,6 @@ OC.L10N.register(
     "Confirm" : "තහවුරු කරන්න",
     "Date:" : "දිනය:",
     "Where:" : "කොහේද:",
-    "Anniversary" : "සංවත්සරය",
-    "Personal" : "පුද්ගලික",
     "A Calendar app for Nextcloud" : "නෙක්ස්ට් ක්ලවුඩ් සඳහා දින දර්ශන යෙදුමකි",
     "Previous day" : "පසුගිය දිනය",
     "Previous week" : "පසුගිය සතිය",
@@ -52,14 +50,13 @@ OC.L10N.register(
     "Unknown" : "නොදන්නා",
     "Accept" : "පිළිගන්න",
     "Decline" : "ප්‍රතික්ෂේප",
-    "More" : "තව",
     "Time:" : "වේලාව:",
+    "Personal" : "පුද්ගලික",
     "Details" : "විස්තර",
     "Close" : "වසන්න",
+    "Anniversary" : "සංවත්සරය",
     "Daily" : "දිනපතා",
     "Weekly" : "සතිපතා",
-    "Other" : "වෙනත්",
-    "Mail" : "තැපෑල",
-    "Birthday" : "උපන් දිනය"
+    "Other" : "වෙනත්"
 },
 "nplurals=2; plural=(n != 1);");
