@@ -55,23 +55,22 @@ OC.L10N.register(
     "Delete file" : "Fshi skedarin",
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Available" : "i disponueshëm",
+    "Done" : "U bë",
     "Unknown" : "I/E panjohur",
     "Accept" : "Prano",
     "Decline" : "Refuzo",
     "Tentative" : "Tentativë",
-    "Send email" : "Dërgo email",
+    "Attendees" : "Pjesëmarrës",
     "Remove group" : "Hiq grupin",
     "All day" : "Gjithë ditën",
     "Repeat" : "Përsërite",
     "never" : "kurrë",
     "after" : "pas",
     "available" : "në gjëndje",
-    "More" : "Më tepër",
     "Global" : "Globale",
     "Subscribe" : "Abonohu",
     "Personal" : "Personale",
     "Details" : "Detajet",
-    "Attendees" : "Pjesëmarrës",
     "Resources" : "Burimet",
     "Close" : "Mbylle",
     "Anniversary" : "Përvjetor",
@@ -85,10 +84,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "E konfirmuar",
     "Canceled" : "Anuluar",
-    "Categories" : "Kategoritë",
-    "Presentation" : "Paraqitje",
-    "Office" : "Zyrë",
-    "Mail" : "Posta",
-    "Birthday" : "Datëlindje"
+    "Categories" : "Kategoritë"
 },
 "nplurals=2; plural=(n != 1);");
